The NITF 2.0 symbol header (sarpy.io.general.nitf_elements.symbol)
==================================================================

.. automodule:: sarpy.io.general.nitf_elements.symbol
    :members:
    :show-inheritance:
    :inherited-members:
